# To-Do

A simple to-do list program.

## Description

A small application to manage multiple to-do lists written in Python 3 and Qt5

## Getting started

* Clone the git repository from https://github.com/berrym/todo.git

* Install a recent version of Python, needs version 3.8+.

* A requirements.txt is provided in the repository so required packages can be installed using pip.
    * pip install -r requirements.txt --user

### Executing program

The main script can be executed from the command line, e.g.

* python3 todo.py

## Help

python3 todo.py --help

## Authors

Copyright 2020
Michael Berry <trismegustis@gmail.com>

## Version History
* 0.1.1
    * Needs Python 3.8 for walrus operator.
    * Improved dialogs for syncing.
    * Serialize network I/O with json.

* 0.1.0
    * Initial Release

## License

This project is licensed under the GNU General Public License version 3, or at your option any later version.

See the COPYING file included in the git repository.
